Attribute VB_Name = "modHyperlinkHelper"
Option Compare Database
Option Explicit

' ****************************** BEGIN COPYRIGHT NOTICE************************************************************
'
' Module modHyperlinkHelper
' Copyright 2016 by Philipp Stiefel (Email: phil@codekabinett.de / http://www.codekabinett.com)
'
' You are granted permission to use this module within your own application, provided
' this copyright notice is left unchanged.
'
' You are also granted permission to redistribute this code as part of your application unless the
' main purpose of the application is the reproduction this sample
'
' You may NOT redistribute this sample as is, without the authors explicit consent!
'
' ****************************** END COPYRIGHT NOTICE************************************************************


' You can use this function in an Access Query to show the data that is really stored
' in your hyperlink column.
Public Function GetHyperlinkRawData(ByVal hyperlinkData As Variant) As Variant
    GetHyperlinkRawData = hyperlinkData
End Function

'This function just extracts the DisplayText from the hyperlink column. If there
'is no DisplayText explicitly defined, it will return the full address including
'the sub-address.
Public Function GetHyperlinkDisplayText(ByVal hyperlinkData As Variant) As Variant

    Const SEPARATOR As String = "#"

    Dim retVal As Variant
    Dim tmpArr As Variant
    
    If IsNull(hyperlinkData) Then
        retVal = hyperlinkData
    Else
        
        tmpArr = Split(hyperlinkData, SEPARATOR)
    
        If Len(tmpArr(0)) > 0 Then
            retVal = tmpArr(0)
        Else
            retVal = tmpArr(1)
            If Len(tmpArr(2)) > 0 Then
                retVal = retVal & "#" & tmpArr(2)
            End If
        End If
    
    End If

    GetHyperlinkDisplayText = retVal

End Function

'GetHyperlinkFullAddress extracts the hyperlink target address including the sub-address. For email addresses
'the function has an optional Boolean argument removeMailto to strip out the mailto:-part of the link and
'just return the plain email address.
Public Function GetHyperlinkFullAddress(ByVal hyperlinkData As Variant, Optional ByVal removeMailto As Boolean) As Variant

    Const SEPARATOR As String = "#"

    Dim retVal As Variant
    Dim tmpArr As Variant
    
    If IsNull(hyperlinkData) Then
        retVal = hyperlinkData
    Else
        
        If InStr(hyperlinkData, SEPARATOR) > 0 Then
            ' I append 4 separators at the end, so I don't have to worry about the
            ' lenght of the array returned by Split()
            hyperlinkData = hyperlinkData & String(4, SEPARATOR)
            tmpArr = Split(hyperlinkData, SEPARATOR)
            
            If Len(tmpArr(1)) > 0 Then
                retVal = tmpArr(1)
                If Len(tmpArr(2)) > 0 Then
                    retVal = retVal & "#" & tmpArr(2)
                End If
            End If
        Else
            retVal = hyperlinkData
        End If
    
        If Left(retVal, 7) = "mailto:" Then
            retVal = Mid(retVal, 8)
        End If
    
    End If

    GetHyperlinkFullAddress = retVal

End Function



